@@ -80,4 +80,11 @@ utils::globalVariables(c("%>%",
                          "SelectIntegrationFeatures",
                          "PrepSCTIntegration",
                          "Phase",
+                         "percentage",
+                         "Immgen.microarray.GSE37448.189",
+                         "Immgen.microarray.GSE15907.653",
+                         "Immgen.GSE124829.190",
+                         "Immgen.GSE122597.83",
+                         "Immgen.GSE122108.412",
+                         "Immgen.GSE109125.205",
                          "yend"))
